{
    package GCLang::CS;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (

        'LangName' => 'Czech',
        
        'Separator' => ': ',
        
        'Warning' => '<b>Varování</b>:
        
Informace získané ze serverů (vyhledávacím pluginem) 
jsou pouze pro <b>osobní použití</b>.

Jakákoliv redistribuce je zakázána bez <b>přímého souhlasu</b> serverů.

K rozlišení, který server vlastní dané informace, můžete použít
<b>tlačítko pod detaily každé položky</b>.',
        
        'AllItemsFiltered' => 'Žádný záznam pro Vaše zadání',
        
#Installation
        'InstallDirInfo' => 'Instaluji do ',
        'InstallMandatory' => 'Povinné součásti',
        'InstallOptional' => 'Volitelné součásti',
        'InstallErrorMissing' => 'Chyba: Musí být nainstalovány následující komponenty Perlu: ',
        'InstallPrompt' => 'Základní adresář pro instalaci [/usr/local]: ',
        'InstallEnd' => 'Konec instalace',
        'InstallNoError' => 'Bez chyb',
        'InstallLaunch' => 'Před použitím aplikace musíte spustit ',
        'InstallDirectory' => 'Základní adresář',
        'InstallTitle' => 'Instalace GCstar',
        'InstallDependencies' => 'Závislosti',
        'InstallPath' => 'Cesta',
        'InstallOptions' => 'Volby',
        'InstallSelectDirectory' => 'Vyberte adresář pro instalaci',
        'InstallWithClean' => 'Odstraňte soubory z adresáře pro instalaci',
        'InstallWithMenu' => 'Přidat GCstar do menu Aplikace',
        'InstallNoPermission' => 'Chyba: Nemáte oprávnění k zápisu do zvoleného adresáře',
        'InstallMissingMandatory' => 'Povinné závislosti chybí. Instalace GCstar není možná, dokud nebudou přidány do systému.',
        'InstallMissingOptional' => 'Několik volitelných součástí chybí. Jejich seznam je níže. GCstar může být nainstalován, ale některé vlastnosti nebudou dostupné.',
        'InstallMissingNone' => 'Všechny potřebné součásti jsou nainstalovány. Instalace může pokračovat.',
        'InstallOK' => 'OK',
        'InstallMissing' => 'Chybí',
        'InstallMissingFor' => 'Chybí',
        'InstallCleanDirectory' => 'Odstraňování souborů programu GCstar v adresáři: ',
        'InstallCopyDirectory' => 'Kopírování souborů do adresáře: ',
        'InstallCopyDesktop' => 'Kopírování souboru pracovní plochy do: ',		#Copying desktop file in

#Update
        'UpdateUseProxy' => 'Použít Proxy (pokud není potřeba, stiskni enter): ',
        'UpdateNoPermission' => 'Nemáte právo zápisu v tomto adresáři: ',
        'UpdateNone' => 'Update není k dispozici',
        'UpdateFileNotFound' => 'Soubor nenalezen',

#Splash
        'SplashInit' => 'Inicializace',
        'SplashLoad' => 'Nahrávám sbírku',
        'SplashDisplay' => 'Zobrazuji sbírku',
        'SplashDone' => 'Hotovo',

#Import from GCfilms
        'GCfilmsImportQuestion' => 'Zdá se, že jste dříve používal(a) GCfilms. Co chcete importovat z GCfilms do GCstar (nebude to mít vliv na GCfilms pokud jej nadále budete chtít používat)?',
        'GCfilmsImportOptions' => 'Nastavení',
        'GCfilmsImportData' => 'Seznam filmů',

#Menus
        'MenuFile' => '_Soubor',
            'MenuNewList' => '_Nová sbírka',
            'MenuHistory' => 'N_edávné sbírky',
            'MenuLend' => 'Zobraz _půjčené položky',
            'MenuImport' => '_Import',	
            'MenuExport' => '_Export',
    
        'MenuEdit'  => '_Úpravy',
            'MenuDuplicate' => '_Duplikuj položku',
            'MenuEditDeleteCurrent' => '_Vymaž položku',
            'MenuEditFields' => '_Změň pole sbírky',			#Change collection fields
            'MenuEditLockItems' => '_Uzamkni sbírku',
    
        'MenuDisplay' => '_Filtr',
            'MenuAdvancedSearch' => '_Pokročilé vyhledávání',
            'MenuViewAllItems' => 'Zobrazit _všechny položky',
            'MenuNoFilter' => '_Vše',
    
        'MenuConfiguration' => '_Nastavení',
            'MenuDisplayOptions' => '_Zobrazené informace',
            'MenuBorrowers' => '_Dlužníci',
            'MenuGenresConversion' => '_Konverze žánru',
        
        'MenuBookmarks' => 'Mé _Sbíky',
            'MenuBookmarksAdd' => '_Přidat aktuální sbírku',
            'MenuBookmarksEdit' => '_Editovat bookmarked sbírky',	# Edit bookmarked collections

        'MenuHelp' => '_Nápověda',
            'MenuHelpContent' => '_Nápověda',
            'MenuAllPlugins' => 'Zobrazit _pluginy',
            'MenuBugReport' => 'Nahlásit _chybu',
            'MenuAbout' => '_O aplikaci GCstar',
    
        'MenuNewWindow' => 'Zobrazit položky v _novém okně',
        
        'ContextExpandAll' => 'Zobraz vše',
        'ContextCollapseAll' => 'Skryj vše',
    
        'DialogEnterNumber' => 'Prosím zadej hodnotu',

        'RemoveConfirm' => 'Opravdu chcete vymazat tuto položku?',
        'DefaultNewItem' => 'Nová položka',
        'NewItemTooltip' => 'Přidat novou položku',
        'NoItemFound' => 'Položka nebyla nalezena. Chcete ji zkusit najít na jiném serveru?',
        'OpenList' => 'Prosím vyberte sbírku',
        'SaveList' => 'Prosím vyberte, kam uložit sbírku',
        'SaveListTooltip' => 'Uložit současnou sbírku',
        'SaveCurrentList' => 'Napřed specifikujte, kam uložit současnou sbírku',
        'SaveUnsavedChanges' => 'Ve sbírce jste provedli změny. Chcete je nyní uložit?',
        'SaveDontSave' => 'Neukládat',
        'PreferencesTooltip' => 'Umožňuje změnu nastavení',
        'ViewTooltip' => 'Změní zobrazení sbírky',
        'PlayTooltip' => 'Přehraje video asociované filmem',

        'StatusSave' => 'Ukládám...',
        'StatusLoad' => 'Nahrávám...',
        'StatusSearch' => 'Hledám...',
        'StatusGetInfo' => 'Stahuji informace...',
        'StatusGetImage' => 'Stahuji obrázek...',
                
        'SaveError' => 'Nemohu uložit seznam. Prosím zkontrolujte přístupová práva a volné místo na disku.',
        'OpenError' => 'Nemohu otevřít seznam. Prosím zkontrolujte přístupová práva.',
        'OpenFormatError' => 'Nemohu otevřít seznam.',
        'ImageError' => 'Adresář vybraný k ukládání obrázků není správný. Prosím vyberte jiný.',
        'OptionsCreationError'=> 'Nemohu vytvořit soubor s nastavením: ',
        'OptionsOpenError'=> 'Nemohu otevřít soubor s nastavením: ',
        'OptionsSaveError'=> 'Nemohu uložit soubor s nastavením: ',
        
        'RandomTooltip' => 'Co budu dělat dnes večer?',
        'RandomError'=> 'Nic nemáte',
        'RandomEnd'=> 'Nic dalšího nemáte',
        'RandomNextTip'=> 'Další tip',
        'RandomOkTip'=> 'Přijmout tento tip',
        
        'AboutTitle' => 'O aplikaci GCstar',
        'AboutDesc' => 'Katalog sbírek',
        'AboutVersion' => 'Verze',
        'AboutTeam' => 'Tým',
        'AboutWho' => 'Tian: Project manager, Programmer
Adolfo González : Programmer',
        'AboutLicense' => 'Distribuováno za podmínek GNU GPL
Logos Copyright le Spektre
http://le-spektre.org',
        'AboutTranslation' => 'Český překlad připravil TomCat1',
        'AboutDesign' => 'Logo a webdesign od le Spektre',

        'ToolbarRandom' => 'Dnes večer',
        
        'ModelsSelect' => 'Vyber typ sbírky',
        'ModelsPersonal' => 'Vlastní šablony',
        'ModelsDefault' => 'Standardní šablony',
        'ModelsList' => 'Typy sbírek',
        'ModelSettings' => 'Nastavení sbírek',
        'ModelNewType' => 'Nový typ sbírky',
        'ModelName' => 'Název nového typu sbírky:',
        'ModelNewField' => 'Nové pole',
        'ModelFieldInformation' => 'Informace',
        'ModelFieldName' => 'Štítek:',
        'ModelFieldType' => 'Typ:',
        'ModelFieldGroup' => 'Skupina:',
        'ModelFieldValues' => 'Hodnoty',
        'ModelFieldInit' => 'Implicitní:',
        'ModelFieldMin' => 'Minimální:',
        'ModelFieldMax' => 'Maximální:',
        'ModelFieldList' => 'Seznam hodnot:',
        'ModelFieldListLegend' => '<i>Oddělovač je čárka</i>',
        'ModelFieldTypeShortText' => 'Krátký text',
        'ModelFieldTypeLongText' => 'Dlouhý text',
        'ModelFieldTypeYesNo' => 'Ano/Ne',
        'ModelFieldTypeNumber' => 'Číslo',
        'ModelFieldTypeDate' => 'Datum',
        'ModelFieldTypeOptions' => 'Předdefinovaný seznam hodnot',
        'ModelFieldTypeImage' => 'Obrázek',
        'ModelFieldTypeSingleList' => 'Jednoduchý seznam',
        'ModelFieldTypeFile' => 'Soubor',
        'ModelFieldParameters' => 'Parametry',
        'ModelFieldHasHistory' => 'Používat historii',
        'ModelFieldFlat' => 'Zobrazit v jedné řadě',
        'ModelFieldStep' => 'Krok přírůstku:',
        'ModelFieldFileFormat' => 'Typ souboru:',
        'ModelFieldFileFile' => 'Prostý soubor',
        'ModelFieldFileImage' => 'Obrázek',
        'ModelFieldFileVideo' => 'Video',
        'ModelFieldFileAudio' => 'Audio',
        'ModelFieldFileProgram' => 'Program',
        'ModelFieldFileUrl' => 'URL',
        'ModelOptionsFields' => 'Přiřazení polí',
        'ModelOptionsFieldsAuto' => 'Automaticky',
        'ModelOptionsFieldsNone' => 'Nic',
        'ModelOptionsFieldsTitle' => 'Nadpis',
        'ModelOptionsFieldsId' => 'Identifikátor',
        'ModelOptionsFieldsCover' => 'Obal',
        'ModelOptionsFieldsPlay' => 'Tlačítko přehrát',
        'ModelCollectionSettings' => 'Nastavení sbírky',
        'ModelCollectionSettingsLending' => 'Položky mohou být půjčeny',
        'ModelFilterActivated' => 'Pole bude ve vyhledávání',
        'ModelFilterComparison' => 'Porovnání',
        'ModelFilterContain' => 'Obsahuje',
        'ModelFilterRange' => 'Rozsah',
        'ModelFilterNumeric' => 'Porovnávání je číselné',
        'ModelFilterQuick' => 'Vytvořit rychlý filtr',
        'ModelTooltipName' => 'Zadejte název pokud chcete šablonu použít v dalších kolekcích. Pokud název nezadáte, bude nastavení uloženo přímo v kolekci',
        'ModelTooltipLabel' => 'Zobrazený název pole',
        'ModelTooltipGroup' => 'Použití pro seskupování polí. Položky bez přiřazené hodnoty budou v implicitní skupině',
        'ModelTooltipHistory' => 'Pro uchování dříve zadaných hodnot do seznamu přiřazenému poli',
        'ModelTooltipFormat' => 'Typ souboru se použije pro rozlišení akce při otevírání souboru tlačítkem Přehrát',
        'ModelTooltipLending' => 'Tato možnost přidá několik polí pro správu půjčování',
        'ModelTooltipNumeric' => 'Hodnoty budou považovány za čísla při porovnání',
        'ModelTooltipQuick' => 'Do menu filtr přidá submenu',			#This will add a submenu in the Filters one

        'ResultsTitle' => 'Vyberte si ze seznamu',
        'ResultsNextTip' => 'Hledat na dalším serveru',
        'ResultsPreview' => 'Náhled',
        
        'OptionsTitle' => 'Možnosti',
        'OptionsBrowser' => 'Webový prohlížeč',
        'OptionsPlayer' => 'Přehrávač videa',
        'OptionsAudio' => 'Přehrávač hudby',
        'OptionsImages' => 'Adresář s obrázky',
        'OptionsUseRelativePaths' => 'Pro obrázky používat relativní cesty',
        'OptionsLayout' => 'Rozložení',
        'OptionsStatus' => 'Zobrazit stavový řádek',
        'OptionsWarning' => 'Varování: Změny v této záložce budou bez efektu až do restartu aplikace',
        'OptionsRemoveConfirm' => 'Před smazáním položky požadovat potvrzení',
        'OptionsAutoSave' => 'Automaticky ukládat sbírku',
        'OptionsAutoLoad' => 'Při startu nahrát předchozí sbírku',
        'OptionsSplash' => 'Zobrazit úvodní obrázek',
        'OptionsImagesTitle' => 'Vyberte adresář pro ukládání obrázků',
        'OptionsProgramTitle' => 'Vyberte webový prohlížeč',
		'OptionsPlugins' => 'Server, odkud stahovat data',
		'OptionsAskPlugins' => 'Zeptat se (všechny servery)',
		'OptionsPluginsMulti' => 'Více serverů',
		'OptionsPluginsMultiAsk' => 'Zeptat se (více serverů)',
		'OptionsPluginsList' => 'Nastavit seznam',
        'OptionsAskImport' => 'Vyberte pole, která se importují',
		'OptionsProxy' => 'Použít proxy',
        'OptionsLang' => 'Jazyk',
        'OptionsMain' => 'Hlavní',
        'OptionsPaths' => 'Cesty',
        'OptionsInternet' => 'Internet',
        'OptionsConveniences' => 'Vlastnosti',
        'OptionsDisplay' => 'Zobrazení',
        'OptionsToolbar' => 'Nástrojová lišta',
        'OptionsToolbars' => {0 => 'Žádná', 1 => 'Malá', 2 => 'Velká'},
        'OptionsToolbarPosition' => 'Umístění',
        'OptionsToolbarPositions' => {0 => 'Nahoře', 1 => 'Dole', 2 => 'Vlevo', 3 => 'Vpravo'},
        'OptionsView' => 'Zobrazení',
        'OptionsViews' => {0 => 'Text', 1 => 'Obrázek', 2 => 'Detailní'},
        'OptionsColumns' => 'Sloupce',
        'OptionsMailer' => 'E-mailer',
        'OptionsSMTP' => 'Server',
        'OptionsFrom' => 'E-mail',
        'OptionsTransform' => 'Členy umístit na konce názvů',
        'OptionsArticles' => 'Členy (odděleny čárkou)',
        'OptionsSearchStop' => 'Umožnit zrušení hledání',
        'OptionsAlwaysOriginal' => 'Použít hlavní titul jako originální titul, pokud není vyplněn',
        'OptionsHistory' => 'Velikost historie',
        'OptionsClearHistory' => 'Vyčistit historii',
		'OptionsStyle' => 'Skin',
        'OptionsDontAsk' => 'Příště se nedotazovat',
        'OptionsPathProgramsGroup' => 'Programy',
        'OptionsPathImagesGroup' => 'Obrázky',
        'OptionsInternetDataGroup' => 'Import dat',
        'OptionsInternetSettingsGroup' => 'Nastavení',
        'OptionsDisplayInformationGroup' => 'Informační panel',
        'OptionsDisplayArticlesGroup' => 'Členy',
        'OptionsImagesDisplayGroup' => 'Zobrazení',
        'OptionsImagesStyleGroup' => 'Styl',
        'OptionsDetailedPreferencesGroup' => 'Předvolby',
        'OptionsFeaturesConveniencesGroup' => 'Nastavení',
        'OptionsPicturesFormat' => 'Předpona použitá pro obrázky:',
        'OptionsPicturesFormatInternal' => 'gcstar__',
        'OptionsPicturesFormatTitle' => 'Titul nebo název asociované položky',
        'OptionsConfigureMailers' => 'Nastavení e-mailových programů',

        'ImagesOptionsButton' => 'Nastavení',
        'ImagesOptionsTitle' => 'Nastavení pro seznam obrázků',
        'ImagesOptionsSelectColor' => 'Vybrat barvu',
        'ImagesOptionsBg' => 'Pozadí',
        'ImagesOptionsBgPicture' => 'Použít obrázek na pozadí',
        'ImagesOptionsFg'=> 'Výběr',
        'ImagesOptionsBgTooltip' => 'Změna barvy pozadí',
        'ImagesOptionsFgTooltip'=> 'Změna barvy výběru',
        'ImagesOptionsSizeLabel' => 'Velikost obrázků',
        'ImagesOptionsSizeList' => {0 => 'Velmi malé', 1 => 'Malé', 2 => 'Středně velké', 3 => 'Velké', 4 => 'Velmi velké'},
        'ImagesOptionsSizeTooltip' => 'Výběr velikosti obrázků',
		        
        'DetailedOptionsTitle' => 'Nastavení detailního seznamu',
        'DetailedOptionsImageSize' => 'Velikost obrázků',
        'DetailedOptionsGroupItems' => 'Řadit podle',
		'DetailedOptionsFields' => 'Výběr zobrazených polí',
		'DetailedOptionsMasterOption' => 'Hlavní skupina je',
		'DetailedOptionsMasterGenerated' => 'Generována automaticky',
		'DetailedOptionsMasterOrdered' => 'Určena podle',

        'ExtractButton' => 'Informace',
        'ExtractTitle' => 'Informace o video souboru',
        'ExtractImport' => 'Použít hodnoty',

        'FieldsListOpen' => 'Nahrát seznam polí ze souboru',
        'FieldsListSave' => 'Uložit seznam polí do souboru',
        'FieldsListError' => 'Tento seznam polí nemůže být použit s tímto typem sbírky',

        'ExportTitle' => 'Export seznamu',
        'ExportFilter' => 'Export pouze zobrazených položek',
        'ExportFieldsTitle' => 'Pole k exportu',
        'ExportFieldsTip' => 'Vyber pole k exportu',
        'ExportWithPictures' => 'Zkopírovat obrázky do podadresáře',

        'ImportListTitle' => 'Import dalšího seznamu',
        'ImportExportData' => 'Data',
        'ImportExportFile' => 'Soubor',
        'ImportExportSave' => 'Prosím vyberte soubor',
        'ImportExportFieldsUnused' => 'Nepoužité pole',
        'ImportExportFieldsUsed' => 'Použité pole',
        'ImportExportFieldsFill' => 'Přidat vše',
        'ImportExportFieldsClear' => 'Odebrat vše',
        'ImportExportFieldsEmpty' => 'Musíte vybrat alespoň jedno pole',
        'ImportExportFileEmpty' => 'Musíte zadat jméno souboru',
        'ImportFieldsTitle' => 'Pole k importu',
        'ImportFieldsTip' => 'Vyberte pole k importu',
        'ImportNewList' => 'Vytvořit novou kolekci',
        'ImportCurrentList' => 'Přidat do stávající kolekce',
        'ImportDropError' => 'Při otevírání souboru se vyskytl problém. Znovu se načte předchozí seznam.',

        'FileOverwrite' => 'Tento soubor již existuje. Chcete jej přepsat?',

        'PanelCompact' => 'Kompaktní',
        'PanelReadOnly' => 'Pouze pro čtení',
        'PanelForm' => 'Záložky',

        'PanelSearchButton' => 'Stáhnout Informace',
        'PanelSearchTip' => 'Hledá informace o tomto názvu na webu',
        'PanelImageTipOpen' => 'Pro výběr jiného obrázku na obrázek klikněte.',
        'PanelImageTipView' => 'Pro zobrazení skutečné velikosti obrázku na něj klikněte.',
        'PanelImageTipMenu' => 'Pod pravým tlačítkem je více voleb.',
        'PanelImageTitle' => 'Vyberte obrázek',
        'PanelImageNoImage' => 'Bez obrázku',
        'PanelSelectFileTitle' => 'Vyberte soubor',

        'PanelFrom' =>'Od',
        'PanelTo' =>'Do',

        'PanelWeb' => 'Zobrazit informace',
        'PanelWebTip' => 'Zobrazí informace o vybrané položce na webu',
        'PanelRemoveTip' => 'Odstraní stávající položku',

        'PanelDateSelect' => 'Vyberte datum',
        'PanelNobody' => 'Nikomu',
        'PanelUnknown' => 'Neznámo',

        'PanelLending' => 'Zápůjčky',
        'PanelBorrower' => 'Dlužník',
        'PanelLendDate' => 'Půjčeno od',
        'PanelHistory' => 'Historie zápůjček',
        'PanelReturned' => 'Položka vrácena',
        'PanelReturnDate' => 'Datum vrácení',
        'PanelLendedYes' => 'Půjčeno',
        'PanelLendedNo' => 'Dostupné',

        'CheckUndef' => 'Nezáleží',
        'CheckYes' => 'Ano',
        'CheckNo' => 'Ne',

        'ToolbarAll' => 'Zobrazit vše',
        'ToolbarAllTooltip' => 'Zobrazí celý seznam',
        'ToolbarGroupBy' => 'Řadit podle',
        'ToolbarGroupByTooltip' => 'Vyberte pole, podle kterého se mají řadit položky seznamu',
        
        'PluginsTitle' => 'Hledat',
        'PluginsQuery' => 'Dotaz',
        'PluginsFrame' => 'Hledat na serveru',
        'PluginsLogo' => 'Logo',
        'PluginsName' => 'Jméno',
        'PluginsSearchFields' => 'Hledat v poli',
        'PluginsAuthor' => 'Autor',
        'PluginsLang' => 'Jazyk',
        'PluginsUseSite' => 'Použít vybraný server pro další hledání',

        'BorrowersTitle' => 'Konfigurace dlužníků',
        'BorrowersList' => 'Dlužníci',
        'BorrowersName' => 'Jméno',
        'BorrowersEmail' => 'E-mail',
        'BorrowersAdd' => 'Přidat',
        'BorrowersRemove' => 'Odebrat',
        'BorrowersEdit' => 'Editace',
        'BorrowersTemplate' => 'Šablona mailu',
        'BorrowersSubject' => 'Předmět mailu',
        'BorrowersNotice1' => '%1 bude nahrazen jménem dlužníka',
        'BorrowersNotice2' => '%2 bude nahrazen názvem položky',
        'BorrowersNotice3' => '%3 bude nahrazen datem výpůjčky',

        'BorrowersImportTitle' => 'Importovat informace o dlužnících',
        'BorrowersImportType' => 'Formát souboru:',
        'BorrowersImportFile' => 'Soubor:',

        'BorrowedTitle' => 'Půjčené položky',
        'BorrowedDate' => 'Od',

        'MailTitle' => 'Poslat e-mail',
        'MailFrom' => 'Od: ',
        'MailTo' => 'Komu: ',
        'MailSubject' => 'Předmět: ',
        'MailSmtpError' => 'Problém s připojením k SMTP serveru',
        'MailSendmailError' => 'Problém se spuštěním sendmailu',

        'SearchTooltip' => 'Prohledává celý seznam',
        'SearchTitle' => 'Hledání',

        'QueryReplaceField' => 'Nahradit v poli',
        'QueryReplaceOld' => 'Současné jméno',
        'QueryReplaceNew' => 'Nové jméno',
        'QueryReplaceLaunch' => 'Nahradit',
        
        'ImportWindowTitle' => 'Vyberte pole k importu',
        'ImportViewPicture' => 'Zobrazit obrázek',
        'ImportSelectAll' => 'Vybrat vše',
        'ImportSelectNone' => 'Nevybírat nic',

        'MultiSiteTitle' => 'Pro hledání použít tyto servery',
        'MultiSiteUnused' => 'Nepoužité servery',
        'MultiSiteUsed' => 'Použité servery',
        'MultiSiteLang' => 'Vybrat české servery',
        'MultiSiteEmptyError' => 'Máte prázdný seznam serverů',
        'MultiSiteClear' => 'Vymazat seznam',
        
        'DisplayOptionsTitle' => 'Zobrazit položky',
        'DisplayOptionsAll' => 'Vybrat vše',
        'DisplayOptionsSearch' => 'Stáhnout informace',

        'GenresTitle' => 'Konverze žánrů',
        'GenresCategoryName' => 'Použít žánr',
        'GenresCategoryMembers' => 'Nahradit žánr',
        'GenresLoad' => 'Nahrát seznam',
        'GenresExport' => 'Uložit seznam do souboru',
        'GenresModify' => 'Upravit konverzi',

        'PropertiesName' => 'Název sbírky',
        'PropertiesOwner' => 'Vlastník',
        'PropertiesEmail' => 'E-mail',
        'PropertiesDescription' => 'Popis',
        'PropertiesFile' => 'Informace o souboru',
        'PropertiesFilePath' => 'Úplná cesta',
        'PropertiesItemsNumber' => 'Počet položek',
        'PropertiesFileSize' => 'Velikost',
        'PropertiesFileSizeSymbols' => ['Bytů', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
        'PropertiesCollection' => 'Vlastnosti sbírky',

        'MailProgramsTitle' => 'Programy pro odesílání mailů',
        'MailProgramsName' => 'Název',
        'MailProgramsCommand' => 'Příkazová řádka',
        'MailProgramsRestore' => 'Obnovit implicitní',
        'MailProgramsAdd' => 'Přidat program',
        'MailProgramsInstructions' => 'V příkazové řádce je provedeno několik substitucí:
 %f je nahrazeno e-mailovou adresou uživatele.
 %t je nahrazeno adresou příjemce.
 %s je nahrazeno předmětem zprávy.
 %b je nahrazeno obsahem zprávy.',

        'BookmarksBookmarks' => 'Záložky',
        'BookmarksFolder' => 'Adresář',
        'BookmarksLabel' => 'Štítek',					#Label
        'BookmarksPath' => 'Cesta',
        'BookmarksNewFolder' => 'Nový adresář',

        'AdvancedSearchType' => 'Typ hledání',
        'AdvancedSearchTypeAnd' => 'Položky odpovídají všem podmínkám',
        'AdvancedSearchTypeOr' => 'Položky odpovídají alespoň jedné podmínce',
        'AdvancedSearchCriteria' => 'Podmínky',
    );
}
1;
